/*
 * CDG Software
 * Copyright (C) 2010 Jeff Gordy
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.cdgsoftware.icl;

import java.util.ArrayList;

import org.apache.log4j.Logger;

import org.cdgsoftware.icl.record.CheckDetailAddendumARecord;
import org.cdgsoftware.icl.record.CheckDetailRecord;

/**
 * The Class ICLItem.
 */
public class ICLItem {
	private CheckDetailRecord checkDetail;
	private ArrayList<CheckDetailAddendumARecord> checkDetailAddendumAList;
	private ArrayList<ImageView> imageViewList;
	//TODO add other records
	/*
	 * private CheckDetailAddendumBRecord checkDetailAddendumB;
	 * private ArrayList<CheckDetailAddendumC> checkDetailAddendumCList;
	 */
	
	static Logger log = Logger.getLogger(ICLItem.class);

	/**
	 * Instantiates a new iCL item.
	 */
	public ICLItem() {
		checkDetailAddendumAList = new ArrayList<CheckDetailAddendumARecord>();
	}

	/**
	 * Instantiates a new iCL item.
	 * 
	 * @param checkDetail the check detail
	 * @param checkDetailAddendumAList the check detail addendum a list
	 * @param imageViewList the image view list
	 */
	public ICLItem(CheckDetailRecord checkDetail,
			ArrayList<CheckDetailAddendumARecord> checkDetailAddendumAList,
			ArrayList<ImageView> imageViewList) {
		super();
		this.checkDetail = checkDetail;
		this.checkDetailAddendumAList = checkDetailAddendumAList;
		this.imageViewList = imageViewList;
	}

	/**
	 * Gets the check detail.
	 * 
	 * @return the check detail
	 */
	public CheckDetailRecord getCheckDetail() {
		return checkDetail;
	}

	/**
	 * Sets the check detail.
	 * 
	 * @param checkDetail the new check detail
	 */
	public void setCheckDetail(CheckDetailRecord checkDetail) {
		this.checkDetail = checkDetail;
	}

	/**
	 * Gets the check detail addendum a list.
	 * 
	 * @return the check detail addendum a list
	 */
	public ArrayList<CheckDetailAddendumARecord> getCheckDetailAddendumAList() {
		return checkDetailAddendumAList;
	}

	/**
	 * Sets the check detail addendum a list.
	 * 
	 * @param checkDetailAddendumAList the new check detail addendum a list
	 */
	public void setCheckDetailAddendumAList(
			ArrayList<CheckDetailAddendumARecord> checkDetailAddendumAList) {
		this.checkDetailAddendumAList = checkDetailAddendumAList;
	}

	/**
	 * Gets the image view list.
	 * 
	 * @return the image view list
	 */
	public ArrayList<ImageView> getImageViewList() {
		return imageViewList;
	}

	/**
	 * Sets the image view list.
	 * 
	 * @param imageViewList the new image view list
	 */
	public void setImageViewList(ArrayList<ImageView> imageViewList) {
		this.imageViewList = imageViewList;
	}

}
